Package 'simmer.mon'

Title: Monitoring Backends for 'simmer'
Description: Provides additional monitoring backends for 'simmer', e.g., the ability to connect the simulation output to a database.
Authors: Iñaki Ucar [aut, cph, cre] (ORCID: <https://orcid.org/0000-0001-6403-5550>)
Maintainer: Iñaki Ucar <[email protected]>
License: MIT + file LICENSE
Version: 0.0.1
Built: 2026-06-04 10:50:22 UTC
Source: https://github.com/r-simmer/simmer.mon

Help Index


simmer.mon: Monitoring Backends for simmer

Description

Provides monitoring backends that can be attached to simmer environments to replace the default in-memory monitor.

Author(s)

Iñaki Ucar

See Also

simmer's homepage http://r-simmer.org and GitHub repository https://github.com/r-simmer/simmer.mon.


Create a DBI Monitor

Description

Methods for creating database-backed (DBI-based) monitor objects.

Usage

monitor_dbi(conn, auto_disconnect = FALSE, keep = FALSE)

Arguments

conn

A DBIConnection object, as returned by dbConnect().

auto_disconnect

whether the connection should be automatically closed when the monitor is deleted. Set to TRUE if you initialised the connection inside the call to memory_dbi.

keep

whether to keep the tables created on exit. By default, tables are removed.

Value

A monitor object.