| Title: | Monitoring Backends for 'simmer' |
|---|---|
| Description: | Provides additional monitoring backends for 'simmer', e.g., the ability to connect the simulation output to a database. |
| Authors: | Iñaki Ucar [aut, cph, cre] (ORCID: <https://orcid.org/0000-0001-6403-5550>) |
| Maintainer: | Iñaki Ucar <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1 |
| Built: | 2026-06-04 10:50:22 UTC |
| Source: | https://github.com/r-simmer/simmer.mon |
Provides monitoring backends that can be attached to simmer
environments to replace the default in-memory monitor.
Iñaki Ucar
simmer's homepage http://r-simmer.org and GitHub repository https://github.com/r-simmer/simmer.mon.
Methods for creating database-backed (DBI-based) monitor objects.
monitor_dbi(conn, auto_disconnect = FALSE, keep = FALSE)monitor_dbi(conn, auto_disconnect = FALSE, keep = FALSE)
conn |
A DBIConnection object, as returned by
|
auto_disconnect |
whether the connection should be automatically closed
when the monitor is deleted. Set to |
keep |
whether to keep the tables created on exit. By default, tables are removed. |
A monitor object.